@@ -74,8 +74,8 @@ HWNewNet::~HWNewNet()
 {
     if (m_game_connected)
     {
-        RawSendNet(QString("QUIT%1%2").arg(delimiter).arg("User quit"));
-        emit disconnected(tr("User quit"));
+        RawSendNet(QString("QUIT%1").arg(delimiter));
+        emit disconnected("");
     }
     NetSocket.flush();
 }
@@ -91,7 +91,7 @@ void HWNewNet::Connect(const QString & hostName, quint16 port, const QString & n
 void HWNewNet::Disconnect()
 {
     if (m_game_connected)
-        RawSendNet(QString("QUIT%1%2").arg(delimiter).arg("User quit"));
+        RawSendNet(QString("QUIT%1").arg(delimiter));
     m_game_connected = false;
 
     NetSocket.disconnectFromHost();
@@ -237,7 +237,12 @@ void HWNewNet::displayError(QAbstractSocket::SocketError socketError)
             emit disconnected(tr("The host was not found. Please check the host name and port settings."));
             break;
         case QAbstractSocket::ConnectionRefusedError:
-            emit disconnected(tr("Connection refused"));
+            if (getHost() == (QString("%1:%2").arg(NETGAME_DEFAULT_SERVER).arg(NETGAME_DEFAULT_PORT)))
+                // Error for official server
+                emit disconnected(tr("The connection was refused by the official server or timed out. Something seems to be wrong with the official server at the moment. This might be a temporary problem. Please try again later."));
+            else
+                // Error for every other host
+                emit disconnected(tr("The connection was refused by the host or timed out. This might have one of the following reasons:\n- The Hedgewars Server program does currently not run on the host\n- The specified port number is incorrect\n- There is a temporary network problem\n\nPlease check the host name and port settings and/or try again later."));
             break;
         default:
             emit disconnected(NetSocket.errorString());
@@ -376,22 +381,50 @@ void HWNewNet::ParseCmd(const QStringList & lst)
             return;
         }
 
-        QString action = HWProto::chatStringToAction(lst[2]);
-
-        if (netClientState == InLobby)
+        QString action;
+        QString message;
+        QString sender = lst[1];
+        // '[' is a special character used in fake nick names of server messages.
+        // Those are supposed to be translated
+        if(!sender.startsWith('['))
         {
-            if (action != NULL)
-                emit lobbyChatAction(lst[1], action);
+            // Normal message
+            message = lst[2];
+            // Another kind of fake nick. '(' nicks are server messages, but they must not be translated
+            if(!sender.startsWith('('))
+            {
+                // Check for action (/me command)
+                action = HWProto::chatStringToAction(message);
+            }
             else
-                emit lobbyChatMessage(lst[1], lst[2]);
+            {
+                // If parenthesis were used, replace them with square brackets
+                // for a consistent style.
+                sender.replace(0, 1, '[');
+                sender.replace(sender.length()-1, 1, ']');
+            }
         }
         else
         {
-            emit chatStringFromNet(HWProto::formatChatMsg(lst[1], lst[2]));
-            if (action != NULL)
-                emit roomChatAction(lst[1], action);
+            // Server message
+            // Server messages are translated client-side
+            message = HWApplication::translate("server", lst[2].toLatin1().constData());
+        }
+
+        if (netClientState == InLobby)
+        {
+            if (!action.isNull())
+                emit lobbyChatAction(sender, action);
             else
-                emit roomChatMessage(lst[1], lst[2]);
+                emit lobbyChatMessage(sender, message);
+        }
+        else
+        {
+            emit chatStringFromNet(HWProto::formatChatMsg(sender, message));
+            if (!action.isNull())
+                emit roomChatAction(sender, action);
+            else
+                emit roomChatMessage(sender, message);
         }
         return;
     }
@@ -865,7 +898,10 @@ void HWNewNet::ParseCmd(const QStringList & lst)
             if (lst.size() < 3)
                 emit chatStringFromNet(tr("%1 *** %2 has left").arg('\x03').arg(lst[1]));
             else
-                emit chatStringFromNet(tr("%1 *** %2 has left (%3)").arg('\x03').arg(lst[1], lst[2]));
+            {
+                QString leaveMsg = QString(lst[2]);
+                emit chatStringFromNet(tr("%1 *** %2 has left (%3)").arg('\x03').arg(lst[1]).arg(HWApplication::translate("server", leaveMsg.toLatin1().constData())));
+            }
             m_playersModel->playerLeftRoom(lst[1]);
             return;
         }
