@@ -54,9 +54,6 @@ HWTeam::HWTeam(const QString & teamname) :
         m_binds[i].action = cbinds[i].action;
         m_binds[i].strbind = QString();
     }
-    m_rounds = 0;
-    m_wins = 0;
-    m_campaignProgress = 0;
     m_color = 0;
 }
 
@@ -83,9 +80,6 @@ HWTeam::HWTeam(const QStringList& strLst) :
 // Checking net teams is probably pointless, but can't hurt.
         if (m_hedgehogs[i].Hat.isEmpty()) m_hedgehogs[i].Hat = "NoHat";
     }
-    m_rounds = 0;
-    m_wins = 0;
-    m_campaignProgress = 0;
     m_color = 0;
 }
 
@@ -114,9 +108,6 @@ HWTeam::HWTeam() :
         m_binds[i].action = cbinds[i].action;
         m_binds[i].strbind = QString();
     }
-    m_rounds = 0;
-    m_wins = 0;
-    m_campaignProgress = 0;
     m_color = 0;
 }
 
@@ -135,9 +126,6 @@ HWTeam::HWTeam(const HWTeam & other) :
     , m_color(other.m_color)
     , m_isNetTeam(other.m_isNetTeam)
     , m_owner(other.m_owner)
-    , m_campaignProgress(other.m_campaignProgress)
-    , m_rounds(other.m_rounds)
-    , m_wins(other.m_wins)
 //      , AchievementProgress(other.AchievementProgress)
 {
 
@@ -160,9 +148,6 @@ HWTeam & HWTeam::operator = (const HWTeam & other)
         m_color = other.m_color;
         m_isNetTeam = other.m_isNetTeam;
         m_owner = other.m_owner;
-        m_campaignProgress = other.m_campaignProgress;
-        m_rounds = other.m_rounds;
-        m_wins = other.m_wins;
         m_color = other.m_color;
     }
 
@@ -179,18 +164,11 @@ bool HWTeam::loadFromFile()
     m_voicepack = teamfile.value("Team/Voicepack", "Default").toString();
     m_flag = teamfile.value("Team/Flag", "hedgewars").toString();
     m_difficulty = teamfile.value("Team/Difficulty", 0).toInt();
-    m_rounds = teamfile.value("Team/Rounds", 0).toInt();
-    m_wins = teamfile.value("Team/Wins", 0).toInt();
-    m_campaignProgress = teamfile.value("Team/CampaignProgress", 0).toInt();
     for(int i = 0; i < HEDGEHOGS_PER_TEAM; i++)
     {
         QString hh = QString("Hedgehog%1/").arg(i);
         m_hedgehogs[i].Name = teamfile.value(hh + "Name", QString("Hedgehog %1").arg(i+1)).toString();
         m_hedgehogs[i].Hat = teamfile.value(hh + "Hat", "NoHat").toString();
-        m_hedgehogs[i].Rounds = teamfile.value(hh + "Rounds", 0).toInt();
-        m_hedgehogs[i].Kills = teamfile.value(hh + "Kills", 0).toInt();
-        m_hedgehogs[i].Deaths = teamfile.value(hh + "Deaths", 0).toInt();
-        m_hedgehogs[i].Suicides = teamfile.value(hh + "Suicides", 0).toInt();
     }
     for(int i = 0; i < BINDS_NUMBER; i++)
         m_binds[i].strbind = teamfile.value(QString("Binds/%1").arg(m_binds[i].action), QString()).toString();
@@ -244,19 +222,12 @@ bool HWTeam::saveToFile()
     teamfile.setValue("Team/Voicepack", m_voicepack);
     teamfile.setValue("Team/Flag", m_flag);
     teamfile.setValue("Team/Difficulty", m_difficulty);
-    teamfile.setValue("Team/Rounds", m_rounds);
-    teamfile.setValue("Team/Wins", m_wins);
-    teamfile.setValue("Team/CampaignProgress", m_campaignProgress);
 
     for(int i = 0; i < HEDGEHOGS_PER_TEAM; i++)
     {
         QString hh = QString("Hedgehog%1/").arg(i);
         teamfile.setValue(hh + "Name", m_hedgehogs[i].Name);
         teamfile.setValue(hh + "Hat", m_hedgehogs[i].Hat);
-        teamfile.setValue(hh + "Rounds", m_hedgehogs[i].Rounds);
-        teamfile.setValue(hh + "Kills", m_hedgehogs[i].Kills);
-        teamfile.setValue(hh + "Deaths", m_hedgehogs[i].Deaths);
-        teamfile.setValue(hh + "Suicides", m_hedgehogs[i].Suicides);
     }
     for(int i = 0; i < BINDS_NUMBER; i++)
         teamfile.setValue(QString("Binds/%1").arg(m_binds[i].action), m_binds[i].strbind);
@@ -430,13 +401,6 @@ QString HWTeam::voicepack() const
     return m_voicepack;
 }
 
-
-// campaignProgress - getter
-unsigned int HWTeam::campaignProgress() const
-{
-    return m_campaignProgress;
-};
-
 // amount of hedgehogs
 unsigned char HWTeam::numHedgehogs() const
 {
@@ -447,15 +411,3 @@ void HWTeam::setNumHedgehogs(unsigned char num)
     m_numHedgehogs = num;
 }
 
-
-
-// rounds+wins - incrementors
-void HWTeam::incRounds()
-{
-    m_rounds++;
-}
-void HWTeam::incWins()
-{
-    m_wins++;
-}
-
