@@ -152,6 +152,7 @@ void PageGameStats::clear()
     labelGameRank->setText("");
     labelGameWin->setText("");
     playerPosition = 0;
+    scriptPlayerPosition = 0;
     lastColor = 0;
 }
 
@@ -299,17 +300,7 @@ void PageGameStats::GameStats(char type, const QString & info)
         }
         case 'T':   // local team stats
         {
-            //AddStatText("<p>local team: " + info + "</p>");
-            QStringList infol = info.split(":");
-            HWTeam team(infol[0]);
-            if(team.fileExists()) // do some better test to avoid influence from scripted/predefined teams?
-            {
-                team.loadFromFile();
-                team.incRounds();
-                if(infol[1].toInt() > 0) // might require some better test for winning condition (or changed flag) ... WIP!
-                    team.incWins(); // should draws count as wins?
-                //team.SaveToFile(); // don't save yet
-            }
+            // unused
             break;
         }
         case 'p' :
@@ -336,7 +327,13 @@ void PageGameStats::GameStats(char type, const QString & info)
             if (lastColor == c) playerPosition--;
             lastColor = c;
 
-            switch (playerPosition)
+            unsigned int realPlayerPosition;
+            if(scriptPlayerPosition == 0)
+                realPlayerPosition = playerPosition;
+            else
+                realPlayerPosition = scriptPlayerPosition;
+
+            switch (realPlayerPosition)
             {
                 case 1:
                     image = "<img src=\":/res/StatsMedal1.png\">";
@@ -363,9 +360,10 @@ void PageGameStats::GameStats(char type, const QString & info)
                 kindOfPoints = QString("");
             }
 
-            message = QString("<p><h2>%1 %2. <font color=\"%4\">%3</font> ").arg(image, QString::number(playerPosition), playername, clanColor.name()) + killstring + "</h2></p>";
+            message = QString("<p><h2>%1 %2. <font color=\"%4\">%3</font> ").arg(image, QString::number(realPlayerPosition), playername, clanColor.name()) + killstring + "</h2></p>";
 
             labelGameRank->setText(labelGameRank->text() + message);
+            scriptPlayerPosition = 0;
             break;
         }
         case 's' :
@@ -398,6 +396,16 @@ void PageGameStats::GameStats(char type, const QString & info)
             AddStatText(message);
             break;
         }
-
+        case 'R' :
+        {
+            scriptPlayerPosition = info.toInt();
+            break;
+        }
+        case 'h' :
+        {
+            QString message = "<p><img src=\":/res/StatsEverAfter.png\"> " + PageGameStats::tr("With everyone having the same clan color, there was no reason to fight. And so the hedgehogs happily lived in peace ever after.") + "</p>";
+            AddStatText(message);
+            break;
+        }
     }
 }
