@@ -508,6 +508,14 @@ QLayout * PageOptions::bodyLayoutDefinition()
             CBMusic->setText(QCheckBox::tr("Music"));
             CBMusic->setWhatsThis(QCheckBox::tr("In-game music"));
             groupGame->layout()->addWidget(CBMusic, 1, 2, 1, 2, Qt::AlignLeft);
+
+            // Dampen
+
+            CBDampenAudio = new QCheckBox(groupGame);
+            //: Checkbox text. If checked, the in-game audio volume is reduced (=dampened) when the game window loses its focus
+            CBDampenAudio->setText(QCheckBox::tr("Dampen when losing focus"));
+            CBDampenAudio->setWhatsThis(QCheckBox::tr("Reduce the game audio volume if the game window has lost its focus"));
+            groupGame->layout()->addWidget(CBDampenAudio, 2, 1, 1, 3, Qt::AlignLeft);
         }
 
         { // group: frontend
@@ -656,6 +664,7 @@ QLayout * PageOptions::bodyLayoutDefinition()
                 if(entryName.isEmpty())
                 {
                     // Show error and the locale identifier
+                    //: In the case of an error, this is shown in the language selection for a language with unknown name. %1 = language code
                     entryName = tr("MISSING LANGUAGE NAME [%1]").arg(lname);
                 }
                 CBLanguage->addItem(entryName, lname);
