@@ -40,11 +40,6 @@ QLayout * PagePlayDemo::bodyLayoutDefinition()
     pageLayout->setColumnStretch(2, 1);
     pageLayout->setRowStretch(2, 100);
 
-    BtnPlayDemo = new QPushButton(this);
-    BtnPlayDemo->setFont(*font14);
-    BtnPlayDemo->setText(QPushButton::tr("Play demo"));
-    pageLayout->addWidget(BtnPlayDemo, 3, 2);
-
     BtnRenameRecord = new QPushButton(this);
     BtnRenameRecord->setText(QPushButton::tr("Rename"));
     pageLayout->addWidget(BtnRenameRecord, 0, 2);
@@ -60,6 +55,23 @@ QLayout * PagePlayDemo::bodyLayoutDefinition()
     return pageLayout;
 }
 
+QLayout * PagePlayDemo::footerLayoutDefinition()
+{
+    QHBoxLayout * bottomLayout = new QHBoxLayout();
+
+    BtnPlayDemo = addButton(tr("Play demo"), bottomLayout, 0, false, Qt::AlignBottom);
+    const QIcon& lp = QIcon(":/res/Start.png");
+    QSize sz = lp.actualSize(QSize(65535, 65535));
+    BtnPlayDemo->setStyleSheet("padding: 5px 10px");
+    BtnPlayDemo->setIcon(lp);
+    BtnPlayDemo->setFixedHeight(50);
+    BtnPlayDemo->setIconSize(sz);
+    BtnPlayDemo->setFlat(true);
+    BtnPlayDemo->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+
+    return bottomLayout;
+}
+
 void PagePlayDemo::connectSignals()
 {
     connect(BtnRenameRecord, SIGNAL(clicked()), this, SLOT(renameRecord()));
@@ -85,12 +97,14 @@ void PagePlayDemo::FillFromDir(RecordType rectype)
         dir.cd("Demos");
         extension = "hwd";
         BtnPlayDemo->setText(QPushButton::tr("Play demo"));
+        BtnPlayDemo->setWhatsThis(tr("Play the selected demo"));
     }
     else
     {
         dir.cd("Saves");
         extension = "hws";
         BtnPlayDemo->setText(QPushButton::tr("Load"));
+        BtnPlayDemo->setWhatsThis(tr("Load the selected game"));
     }
     dir.setFilter(QDir::Files);
 
@@ -122,8 +136,8 @@ void PagePlayDemo::renameRecord()
     {
         QMessageBox recordMsg(this);
         recordMsg.setIcon(QMessageBox::Warning);
-        recordMsg.setWindowTitle(QMessageBox::tr("Record Play - Error"));
-        recordMsg.setText(QMessageBox::tr("Please select record from the list"));
+        recordMsg.setWindowTitle(QMessageBox::tr("Error"));
+        recordMsg.setText(QMessageBox::tr("Please select a file from the list."));
         recordMsg.setWindowModality(Qt::WindowModal);
         recordMsg.exec();
         return ;
@@ -149,8 +163,8 @@ void PagePlayDemo::renameRecord()
         {
             QMessageBox renameMsg(this);
             renameMsg.setIcon(QMessageBox::Warning);
-            renameMsg.setWindowTitle(QMessageBox::tr("Record Play - Error"));
-            renameMsg.setText(QMessageBox::tr("Cannot rename to ") + newfullname);
+            renameMsg.setWindowTitle(QMessageBox::tr("Error"));
+            renameMsg.setText(QMessageBox::tr("Cannot rename file to %1.").arg(newfullname));
             renameMsg.setWindowModality(Qt::WindowModal);
             renameMsg.exec();
         }
@@ -166,8 +180,8 @@ void PagePlayDemo::removeRecord()
     {
         QMessageBox recordMsg(this);
         recordMsg.setIcon(QMessageBox::Warning);
-        recordMsg.setWindowTitle(QMessageBox::tr("Record Play - Error"));
-        recordMsg.setText(QMessageBox::tr("Please select record from the list"));
+        recordMsg.setWindowTitle(QMessageBox::tr("Error"));
+        recordMsg.setText(QMessageBox::tr("Please select a file from the list."));
         recordMsg.setWindowModality(Qt::WindowModal);
         recordMsg.exec();
         return ;
@@ -181,8 +195,8 @@ void PagePlayDemo::removeRecord()
     {
         QMessageBox removeMsg(this);
         removeMsg.setIcon(QMessageBox::Warning);
-        removeMsg.setWindowTitle(QMessageBox::tr("Record Play - Error"));
-        removeMsg.setText(QMessageBox::tr("Cannot delete file ") + rfile.fileName());
+        removeMsg.setWindowTitle(QMessageBox::tr("Error"));
+        removeMsg.setText(QMessageBox::tr("Cannot delete file %1.").arg(rfile.fileName()));
         removeMsg.setWindowModality(Qt::WindowModal);
         removeMsg.exec();
     }
