@@ -170,9 +170,9 @@ QLayout * PageVideos::bodyLayoutDefinition()
                                            Qt::TextSelectableByKeyboard |
                                            Qt::LinksAccessibleByMouse |
                                            Qt::LinksAccessibleByKeyboard);
-        labelDesc->setTextFormat(Qt::RichText);
+        labelDesc->setTextFormat(Qt::PlainText);
         labelDesc->setWordWrap(true);
-        labelDesc->setOpenExternalLinks(true);
+        labelDesc->setOpenExternalLinks(false);
 
         // buttons: play and delete
         btnPlay = new QPushButton(QPushButton::tr("Play"), pDescGroup);
@@ -531,8 +531,6 @@ void PageVideos::updateDescription()
             item->prefix.truncate(pt);
     }
 
-    desc.replace("\n", "<br/>");
-
     labelDesc->setText(desc);
 
     if (!item->prefix.isEmpty())
@@ -594,9 +592,9 @@ void PageVideos::deleteSelectedFiles()
     if (reallyDeleteMsg.exec() != QMessageBox::Ok)
         return;
 
-    // remove
+    // abort / remove
     if (!item->ready())
-        item->pRecorder->deleteLater();
+        item->pRecorder->abort();
     else
     {
         cfgdir->remove("Videos/" + item->name);
