@@ -100,12 +100,12 @@ About::About(QWidget * parent) :
     //: For the version numbers of Hedgewars' software dependencies
     QString libinfo = QString(tr("Dependency versions:") + QString("<br>"));
 
-#ifdef __GNUC__
+#if defined(__GNUC__)
     libinfo.append(QString(tr("<a href=\"https://gcc.gnu.org\">GCC</a>: %1")).arg(__VERSION__));
-    libinfo.append(QString("<br>"));
 #else
-    libinfo.append(QString(tr("Unknown Compiler")).arg(__VERSION__) + QString("<br>"));
+    libinfo.append(QString(tr("Unknown Compiler")));
 #endif
+    libinfo.append(QString("<br>"));
 
     const SDL_version *sdl_ver;
     SDL_version sdl_version;
