@@ -109,7 +109,8 @@ FeedbackDialog::FeedbackDialog(QWidget * parent) : QDialog(parent)
 
     CheckSendSpecs = new QCheckBox();
     CheckSendSpecs->setText(QLabel::tr("Send system information"));
-    CheckSendSpecs->setChecked(true);
+    CheckSendSpecs->setChecked(false);
+    CheckSendSpecs->setToolTip(tr("This is optional, but this information might help us to resolve bugs and other technical problems."));
     BtnViewInfo = new QPushButton(tr("View"));
     BtnViewInfo->setFixedHeight(40);
     feedbackLayout->addWidget(CheckSendSpecs, 0, 2, 2, 1);
