@@ -27,11 +27,13 @@ import Control.Monad
 import Control.Monad.Reader
 --------------------------------------
 import CoreTypes
+import Consts
 import Utils
 import HandlerUtils
 import RoomsAndClients
 import EngineInteraction
 import Votes
+import CommandHelp
 
 startGame :: Reader (ClientIndex, IRnC) [Action]
 startGame = do
@@ -72,8 +74,9 @@ handleCmd_inRoom ["CHAT", msg] = do
     s <- roomOthersChans
     return [AnswerClients s ["CHAT", n, msg]]
 
-handleCmd_inRoom ["PART"] = return [MoveToLobby "part"]
-handleCmd_inRoom ["PART", msg] = return [MoveToLobby $ "part: " `B.append` msg]
+-- Leave room normally
+handleCmd_inRoom ["PART"] = return [MoveToLobby ""]
+handleCmd_inRoom ["PART", _] = return [MoveToLobby ""]
 
 
 handleCmd_inRoom ("CFG" : paramName : paramStrs)
@@ -144,7 +147,7 @@ handleCmd_inRoom ("ADD_TEAM" : tName : color : grave : fort : voicepack : flag :
                 AnswerClients roomChans ["HH_NUM", tName, showB $ hhnum newTeam]
                 ]
         where
-        canAddNumber rt = (48::Int) - (sum $ map hhnum rt)
+        canAddNumber rt = (cMaxHHs) - (sum $ map hhnum rt)
         findTeam = find (\t -> tName == teamname t) . teams
         dif = readInt_ difStr
         hhsList [] = []
@@ -153,7 +156,7 @@ handleCmd_inRoom ("ADD_TEAM" : tName : color : grave : fort : voicepack : flag :
         newTeamHHNum rt p = min p (canAddNumber rt)
         maxTeams r
             | roomProto r < 38 = 6
-            | otherwise = 8
+            | otherwise = cMaxTeams
 
 
 handleCmd_inRoom ["REMOVE_TEAM", tName] = do
@@ -196,7 +199,7 @@ handleCmd_inRoom ["HH_NUM", teamName, numberStr] = do
             [ProtocolError $ loc "You're not the room master!"]
         else if isNothing maybeTeam then
             []
-        else if hhNumber < 1 || hhNumber > 8 || hhNumber > canAddNumber r + hhnum team then
+        else if hhNumber < 1 || hhNumber > cHogsPerTeam || hhNumber > canAddNumber r + hhnum team then
             [AnswerClients clChan ["HH_NUM", teamName, showB $ hhnum team]]
         else
             [ModifyRoom $ modifyTeam team{hhnum = hhNumber},
@@ -204,7 +207,7 @@ handleCmd_inRoom ["HH_NUM", teamName, numberStr] = do
     where
         hhNumber = readInt_ numberStr
         findTeam = find (\t -> teamName == teamname t) . teams
-        canAddNumber = (-) 48 . sum . map hhnum . teams
+        canAddNumber = (-) cMaxHHs . sum . map hhnum . teams
 
 
 
@@ -330,21 +333,27 @@ handleCmd_inRoom ["ROOM_NAME", newName] = roomAdminOnly $ do
 
 handleCmd_inRoom ["KICK", kickNick] = roomAdminOnly $ do
     (thisClientId, rnc) <- ask
-    maybeClientId <- clientByNick kickNick
+    maybeKickId <- clientByNick kickNick
     rm <- thisRoom
-    let kickId = fromJust maybeClientId
+    let kickId = fromJust maybeKickId
     let kickCl = rnc `client` kickId
     let sameRoom = clientRoom rnc thisClientId == clientRoom rnc kickId
     let notOnly2Players = (length . group . sort . map teamowner . teams $ rm) > 2
-    return
-        [KickRoomClient kickId |
-            isJust maybeClientId
-            && (kickId /= thisClientId)
-            && sameRoom
-            && (not $ hasSuperPower kickCl)
-            && ((isNothing $ gameInfo rm) || notOnly2Players || teamsInGame kickCl == 0)
-        ]
-
+    return $
+        -- Catch some error conditions
+        if (isNothing maybeKickId) then
+            [Warning $ loc "Player is not online."]
+        else if (kickId == thisClientId) then
+            [Warning $ loc "You can't kick yourself!"]
+        else if (not ((isNothing $ gameInfo rm) || notOnly2Players || teamsInGame kickCl == 0)) then
+            [Warning $ loc "You can't kick the only other player!"]
+        else if (not sameRoom) then
+            [Warning $ loc "The player is not in your room."]
+        else if (hasSuperPower kickCl) then
+            [Warning $ loc "This player is protected from being kicked."]
+        else
+            -- Kick!
+            [KickRoomClient kickId]
 
 handleCmd_inRoom ["DELEGATE", newAdmin] = do
     (thisClientId, rnc) <- ask
@@ -354,20 +363,26 @@ handleCmd_inRoom ["DELEGATE", newAdmin] = do
     thisRoomMasterId <- liftM masterID thisRoom
     let newAdminId = fromJust maybeClientId
     let sameRoom = clientRoom rnc thisClientId == clientRoom rnc newAdminId
-    return
-        [ChangeMaster (Just newAdminId) |
-            (master || serverAdmin)
-                && isJust maybeClientId
-                && (Just newAdminId /= thisRoomMasterId)
-                && sameRoom]
-
+    return $
+        if (not (master || serverAdmin)) then
+            [Warning $ loc "You're not the room master or a server admin!"]
+        else if (isNothing maybeClientId) then
+            [Warning $ loc "Player is not online."]
+        else if (Just newAdminId == thisRoomMasterId) then
+            [Warning $ loc "You're already the room master."]
+        else if (not sameRoom) then
+            [Warning $ loc "The player is not in your room."]
+        else
+            [ChangeMaster (Just newAdminId)]
 
 handleCmd_inRoom ["TEAMCHAT", msg] = do
     cl <- thisClient
     chans <- roomSameClanChans
     return [AnswerClients chans ["EM", engineMsg cl]]
     where
-        engineMsg cl = toEngineMsg $ B.concat ["b", nick cl, " (team): ", msg, "\x20\x20"]
+        -- This is formatted in a way so it can parsed by engine to make it translatable
+        -- Format: b<PLAYER NAME>]<MESSAGE>
+        engineMsg cl = toEngineMsg $ B.concat ["b", nick cl, "]", msg]
 
 
 handleCmd_inRoom ["BAN", banNick] = do
@@ -390,35 +405,66 @@ handleCmd_inRoom ("RND":rs) = do
     return [AnswerClients s ["CHAT", n, B.unwords $ "/rnd" : rs], Random s rs]
 
 
-handleCmd_inRoom ["MAXTEAMS", n] = roomAdminOnly $ do
+handleCmd_inRoom ["MAXTEAMS", n] = do
     cl <- thisClient
     let m = readInt_ n
-    if m < 2 || m > 8 then
-        return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/maxteams: specify number from 2 to 8"]]
+    if not $ isMaster cl then
+        return [Warning $ loc "You're not the room master!"]
+    else if m < 2 || m > cMaxTeams then
+        return [Warning $ loc "/maxteams: specify number from 2 to 8"]
     else
         return [ModifyRoom (\r -> r{teamsNumberLimit = m})]
 
+handleCmd_inRoom ["MAXTEAMS"] = handleCmd_inRoom ["MAXTEAMS", ""]
+
 handleCmd_inRoom ["FIX"] = serverAdminOnly $
     return [ModifyRoom (\r -> r{isSpecial = True})]
 
-handleCmd_inRoom ["UNFIX"] = serverAdminOnly $
-    return [ModifyRoom (\r -> r{isSpecial = False})]
+handleCmd_inRoom ["UNFIX"] = serverAdminOnly $ do
+    cl <- thisClient
+    return $ if not $ isMaster cl then
+                 [Warning $ loc "You're not the room master!"]
+             else
+                 [ModifyRoom (\r -> r{isSpecial = False})]
+
+handleCmd_inRoom ["HELP"] = do
+    cl <- thisClient
+    if isAdministrator cl then
+        return (cmdHelpActionList [sendChan cl] cmdHelpRoomAdmin)
+    else
+        return (cmdHelpActionList [sendChan cl] cmdHelpRoomPlayer)
 
 handleCmd_inRoom ["GREETING", msg] = do
     cl <- thisClient
     rm <- thisRoom
-    return [ModifyRoom (\r -> r{greeting = msg}) | isAdministrator cl || (isMaster cl && (not $ isSpecial rm))]
-
+    return $ if (not (isAdministrator cl || (isMaster cl && (not $ isSpecial rm)))) then
+                 [Warning $ loc "You're not the room master or a server admin!"]
+             else
+                 [ModifyRoom (\r -> r{greeting = msg}),
+                  AnswerClients [sendChan cl]
+                      ["CHAT", nickServer,
+                          if B.null msg then
+                              loc "Greeting message cleared."
+                          else
+                              loc "Greeting message set."
+                      ]]
 
 handleCmd_inRoom ["CALLVOTE"] = do
     cl <- thisClient
     return [AnswerClients [sendChan cl]
-        ["CHAT", "[server]", loc "Available callvote commands: kick <nickname>, map <name>, pause, newseed, hedgehogs"]
+        ["CHAT", nickServer, loc "Available callvote commands: kick <nickname>, map <name>, pause, newseed, hedgehogs"]
         ]
 
 handleCmd_inRoom ["CALLVOTE", "KICK"] = do
     cl <- thisClient
-    return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote kick: You need to specify a nickname."]]
+    rm <- thisRoom
+    return
+        [Warning $
+        if isJust $ masterID rm then
+            loc "/callvote kick: This is only allowed in rooms without a room master."
+        else
+            loc "/callvote kick: You need to specify a nickname."
+        ]
 
 handleCmd_inRoom ["CALLVOTE", "KICK", nickname] = do
     (thisClientId, rnc) <- ask
@@ -429,18 +475,25 @@ handleCmd_inRoom ["CALLVOTE", "KICK", nickname] = do
     let sameRoom = clientRoom rnc thisClientId == clientRoom rnc kickId
 
     if isJust $ masterID rm then
-        return []
+        return [Warning $ loc "/callvote kick: This is only allowed in rooms without a room master."]
         else
         if isJust maybeClientId && sameRoom then
             startVote $ VoteKick nickname
             else
-            return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote kick: No such user!"]]
+            return [Warning $ loc "/callvote kick: No such user!"]
 
 
 handleCmd_inRoom ["CALLVOTE", "MAP"] = do
+    -- Display list of available maps for voting
     cl <- thisClient
     s <- liftM (Map.keys . roomSaves) thisRoom
-    return [AnswerClients [sendChan cl] ["CHAT", "[server]", B.concat ["callvote map: ", B.intercalate ", " s]]]
+    return [AnswerClients [sendChan cl]
+        ["CHAT", nickServer,
+            if (not $ null s) then
+                (B.concat ["/callvote map: ", B.intercalate ", " s])
+            else
+                loc "/callvote map: No maps available."
+        ]]
 
 
 handleCmd_inRoom ["CALLVOTE", "MAP", roomSave] = do
@@ -450,7 +503,7 @@ handleCmd_inRoom ["CALLVOTE", "MAP", roomSave] = do
     if Map.member roomSave $ roomSaves rm then
         startVote $ VoteMap roomSave
         else
-        return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote map: No such map!"]]
+        return [Warning $ loc "/callvote map: No such map!"]
 
 
 handleCmd_inRoom ["CALLVOTE", "PAUSE"] = do
@@ -460,35 +513,44 @@ handleCmd_inRoom ["CALLVOTE", "PAUSE"] = do
     if isJust $ gameInfo rm then
         startVote VotePause
         else 
-        return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote pause: No game in progress!"]]
+        return [Warning $ loc "/callvote pause: No game in progress!"]
 
+handleCmd_inRoom ["CALLVOTE", "PAUSE", _] = handleCmd_inRoom ["CALLVOTE", "PAUSE"]
 
 handleCmd_inRoom ["CALLVOTE", "NEWSEED"] = do
     startVote VoteNewSeed
 
+handleCmd_inRoom ["CALLVOTE", "NEWSEED", _] = handleCmd_inRoom ["CALLVOTE", "NEWSEED"]
 
 handleCmd_inRoom ["CALLVOTE", "HEDGEHOGS"] = do
     cl <- thisClient
-    return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote hedgehogs: Specify number from 1 to 8."]]
+    return [Warning $ loc "/callvote hedgehogs: Specify number from 1 to 8."]
 
 
 handleCmd_inRoom ["CALLVOTE", "HEDGEHOGS", hhs] = do
     cl <- thisClient
     let h = readInt_ hhs
 
-    if h > 0 && h <= 8 then
+    if h > 0 && h <= cHogsPerTeam then
         startVote $ VoteHedgehogsPerTeam h
         else
-        return [AnswerClients [sendChan cl] ["CHAT", "[server]", loc "/callvote hedgehogs: Specify number from 1 to 8."]]
+        return [Warning $ loc "/callvote hedgehogs: Specify number from 1 to 8."]
 
+handleCmd_inRoom ["CALLVOTE", _] = handleCmd_inRoom ["CALLVOTE"]
+handleCmd_inRoom ["CALLVOTE", _, _] = handleCmd_inRoom ["CALLVOTE"]
 
 handleCmd_inRoom ("VOTE" : m : p) = do
     cl <- thisClient
     let b = if m == "YES" then Just True else if m == "NO" then Just False else Nothing
     if isJust b then
         voted (p == ["FORCE"]) (fromJust b)
-        else
-        return [AnswerClients [sendChan cl] ["CHAT", "[server]", "/vote: Please use 'yes' or 'no'."]]
+    else
+        return [Warning $
+            if (p == ["FORCE"]) then
+                loc "/force: Please use 'yes' or 'no'."
+            else
+                loc "/vote: Please use 'yes' or 'no'."
+        ]
 
 
 handleCmd_inRoom ["SAVE", stateName, location] = serverAdminOnly $ do
