@@ -183,9 +183,7 @@ function ManageTeleporterEffects()
 			-- smoketrace and eviltrace are not effected by wind?
 			-- chunk is a LR falling gear
 			local tempE = AddVisualGear(eX, eY, vgtDust, 0, false)
-			if tempE ~= 0 then
-				SetVisualGearValues(tempE, eX, eY, nil, nil, nil, nil, nil, nil, nil, fCol[i])
-			end
+			SetVisualGearValues(tempE, eX, eY, nil, nil, nil, nil, nil, nil, nil, fCol[i])
 		end
 	end
 end
@@ -285,7 +283,7 @@ function FlagDeleted(gear)
 				fNeedsRespawn[bbq] = true
 				fCaptures[wtf] = fCaptures[wtf] +1
 
-				AddCaption(string.format(loc("%s has scored!"), GetHogTeamName(CurrentHedgehog)), 0xFFFFFFFF, capgrpGameState)
+				AddCaption(string.format(loc("%s has scored!"), GetHogTeamName(CurrentHedgehog)), capcolDefault, capgrpGameState)
 				for i=1, #clanTeams[wtf] do
 					SetTeamLabel(clanTeams[wtf][i], fCaptures[wtf])
 				end
@@ -582,6 +580,10 @@ function onGameStart()
 	fSpawnX[1] = 3123
 	fSpawnY[1] = 1747
 
+	if ClansCount < 2 then
+		return
+	end
+
 	for i = 0, 1 do
 		fGear[i] = SpawnFakeAmmoCrate(fSpawnX[i],fSpawnY[i],false,false)
 		fCirc[i] = AddVisualGear(fSpawnX[i],fSpawnY[i],vgtCircle,0,true)
@@ -677,7 +679,7 @@ function onAmmoStoreInit()
 end
 
 
-function onGearResurrect(gear)
+function onGearResurrect(gear, vGear)
 
 	-- mark the flag thief as dead if he needed a respawn
 	for i = 0,1 do
@@ -693,7 +695,9 @@ function onGearResurrect(gear)
 		FindPlace(gear, false, 2048, LAND_WIDTH)
 	end
 
-	AddVisualGear(GetX(gear), GetY(gear), vgtBigExplosion, 0, false)
+	if vGear then
+		SetVisualGearValues(vGear, GetX(gear), GetY(gear))
+	end
 
 end
 
