@@ -86,7 +86,7 @@ end
 
 function onGameInit()
     -- Ensure people get same map for same theme
-    TurnTime = 999999999
+    TurnTime = MAX_TURN_TIME
     CaseFreq = 0
     Explosives = 0
     MineDudPercent = 0
@@ -113,7 +113,7 @@ end
 
 function onGearDelete(gear)
     if gear == MrMine then
-        AddCaption(loc("Once you set off the proximity trigger, Mr. Mine is not your friend"), 0xFFFFFFFF, capgrpMessage2)
+        AddCaption(loc("Once you set off the proximity trigger, Mr. Mine is not your friend"), capcolDefault, capgrpMessage2)
         MrMine = nil
     elseif GetGearType(gear) == gtCake then
         Cake = nil
@@ -272,16 +272,13 @@ function onGameTick20()
     --end
 
     for s,i in pairs(Stars) do
-        g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(s)
-        if g1 > WaterLine + 500 then
+        local _, Y = GetVisualGearValues(s)
+        if Y ~= nil and Y > WaterLine + 500 then
             DeleteVisualGear(s)
             Stars[s] = nil
+        elseif Y == nil then
+            Stars[s] = nil
         end
-        --else  wasn't really visible, pointless.
-        --    g5 = g5+1
-        --    if g5 > 360 then g5 = 0 end
-        --    SetVisualGearValues(s, g1, g2, g3, g4, g5, g6, g7, g8, g9, g10)
-        --end
     end
 
     -- This will be executed if a player reached home in multiplayer
@@ -351,7 +348,7 @@ function onGameTick20()
 
     if CurrentHedgehog ~= nil and TurnTimeLeft > 0 and band(GetState(CurrentHedgehog),gstHHDriven) ~= 0 then
         if MaxHeight < delayHeight and
-           TurnTimeLeft<(999999999-delayTime) and 
+           TurnTimeLeft<(MAX_TURN_TIME-delayTime) and
             MaxHeight > 286 and WaterLine > 286 then
             if waterAccel ~= 0 then
                 SetWaterLine(WaterLine-(baseWaterSpeed+div(getActualHeight(MaxHeight)*100,waterAccel)))
@@ -360,19 +357,21 @@ function onGameTick20()
             end
         end
         if y > 0 and y < 30000 and MaxHeight > 286 and math.random(y) < 500 then
-            local s = AddVisualGear(0, 0, vgtStraightShot, 0, true)
-            local c = div(250000,y)
-            if c > 255 then c = 255 end
-            c = c * 0x10000 + 0xFF0000FF
-            SetVisualGearValues(s,
-                math.random(2048), -5000, 0, -1-(1/y*1000), 
-                math.random(360),
-                0,
-                999999999, -- frameticks
-                sprStar, -- star
-                0, c)
-                --,  0xFFCC00FF) -- could be fun to make colour shift as you rise...
-            Stars[s] = 1
+            local s = AddVisualGear(0, 0, vgtStraightShot, 0, false)
+            if s then
+                local c = div(250000,y)
+                if c > 255 then c = 255 end
+                c = c * 0x10000 + 0xFF0000FF
+                SetVisualGearValues(s,
+                    math.random(2048), -5000, 0, -1-(1/y*1000),
+                    math.random(360),
+                    0,
+                    999999999, -- frameticks
+                    sprStar, -- star
+                    0, c)
+                    --,  0xFFCC00FF) -- could be fun to make colour shift as you rise...
+                Stars[s] = 1
+            end
         end
 
         local vx, vy = GetGearVelocity(CurrentHedgehog)
@@ -429,7 +428,7 @@ function onGameTick20()
             end
             -- FIXME: Hog is also in winning box if it just walks into the chair from the left, touching it. Intentional?
             if not YouWon and not YouLost and gearIsInBox(CurrentHedgehog, 1920, 252, 50, 50) then
-                AddCaption(loc("Victory!"), 0xFFFFFFFF, capgrpGameState)
+                AddCaption(loc("Victory!"), capcolDefault, capgrpGameState)
                 ShowMission(loc("Climb Home"),
                             loc("Made it!"),
                             string.format(loc("Ahhh, home, sweet home. Made it in %d seconds."), roundedFinishTime),
@@ -464,7 +463,7 @@ function onGameTick20()
                     (not MrMine or (MrMine and band(GetState(MrMine), gstAttacking) == 0)) then
                 -- Player managed to reach home in multiplayer.
                 -- Stop hog, disable controls, celebrate victory and continue the game after 4 seconds.
-                AddCaption(string.format(loc("%s climbed home in %d seconds!"), GetHogName(CurrentHedgehog), roundedFinishTime), 0xFFFFFFFF, capgrpGameState)
+                AddCaption(string.format(loc("%s climbed home in %d seconds!"), GetHogName(CurrentHedgehog), roundedFinishTime), capcolDefault, capgrpGameState)
                 SendStat(siCustomAchievement, string.format(loc("%s (%s) reached home in %.3f seconds."), GetHogName(CurrentHedgehog), GetHogTeamName(CurrentHedgehog), finishTime))
                 makeMultiPlayerWinnerStat(CurrentHedgehog)
                 PlaySound(sndVictory, CurrentHedgehog)
@@ -537,7 +536,6 @@ function onGameTick20()
                     hTagHeight = MaxHeight
                     if hTag ~= nil then DeleteVisualGear(hTag) end
                     hTag = AddVisualGear(0, 0, vgtHealthTag, 0, true)
-                    local g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(hTag)
                     local score = 32640-hTagHeight
                     -- snagged from space invasion
                     SetVisualGearValues (
@@ -548,7 +546,7 @@ function onGameTick20()
                             0,          --dy
                             1.1,        --zoom
                             1,          --~= 0 means align to screen
-                            g7,         --frameticks
+                            nil,        --frameticks
             -- 116px off bottom for lowest rock, 286 or so off top for position of chair
             -- 32650 is "0"
                             score,    --value
@@ -572,7 +570,6 @@ function onGameTick20()
                     if not isSinglePlayer then
                         if rTag ~= nil then DeleteVisualGear(rTag) end
                         rTag = AddVisualGear(0, 0, vgtHealthTag, 0, true)
-                        local g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(hTag)
                         -- snagged from space invasion
                         SetVisualGearValues (
                             rTag,        --id
@@ -582,7 +579,7 @@ function onGameTick20()
                             0,          --dy
                             1.1,        --zoom
                             1,          --~= 0 means align to screen
-                            g7,         --frameticks
+                            nil,        --frameticks
             -- 116px off bottom for lowest rock, 286 or so off top for position of chair
             -- 32650 is "0"
                             getActualHeight(RecordHeight),    --value
@@ -595,7 +592,6 @@ function onGameTick20()
             if MaxHeight > 286 then
                 if tTag ~= nil then DeleteVisualGear(tTag) end
                 tTag = AddVisualGear(0, 0, vgtHealthTag, 0, true)
-                local g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(tTag)
                 -- snagged from space invasion
                 SetVisualGearValues (
                     tTag,        --id
@@ -605,7 +601,7 @@ function onGameTick20()
                     0,          --dy
                     1.1,        --zoom
                     1,          --~= 0 means align to screen
-                    g7,         --frameticks
+                    nil,        --frameticks
                     (GameTime-startTime)/1000,    --value
                     99999999999,--timer
                     0xffffffff
