@@ -244,7 +244,7 @@ function WonderAlive()
     AnimInsertStepNext({func = AnimSay, args = {natives[leaksNum], loc("Why would they do this?"), SAY_SAY, 6000}})
     AnimInsertStepNext({func = AnimSay, args = {natives[wiseNum], loc("It must be the aliens' deed."), SAY_SAY, 5000}})
     AnimInsertStepNext({func = AnimSay, args = {natives[wiseNum], loc("Do not laugh, inexperienced one, for he speaks the truth!"), SAY_SAY, 10000}})
-    AnimInsertStepNext({func = AnimSay, args = {natives[leaksNum], loc("Yeah, sure! I died. Hillarious!"), SAY_SAY, 6000}})
+    AnimInsertStepNext({func = AnimSay, args = {natives[leaksNum], loc("Yeah, sure! I died. Hilarious!"), SAY_SAY, 6000}})
     AnimInsertStepNext({func = AnimSay, args = {gearr, loc("You're...alive!? But we saw you die!"), SAY_SAY, 6000}})
     AnimInsertStepNext({func = AnimSay, args = {gearr, loc("Huh?"), SAY_SAY, 2000}})
     AnimInsertStepNext({func = AnimSay, args = {natives[leaksNum], loc("Wow, what a dream!"), SAY_SAY, 3000}})
@@ -276,7 +276,7 @@ function ExplainAlive()
     AnimSetGearPosition(cyborg, unpack(cyborgPos))
     AnimInsertStepNext({func = AnimCustomFunction, args = {water, HideCyborg, {}}})
     AnimInsertStepNext({func = AnimSwitchHog, args = {water}})
-    AnimInsertStepNext({func = AnimSay, args = {cyborg, loc("The answer is...entertaintment. You'll see what I mean."), SAY_SAY, 8000}})
+    AnimInsertStepNext({func = AnimSay, args = {cyborg, loc("The answer is ... entertainment. You'll see what I mean."), SAY_SAY, 8000}})
     AnimInsertStepNext({func = AnimSay, args = {cyborg, loc("You're probably wondering why I brought you back ..."), SAY_SAY, 8000}})
   end
 end
@@ -392,7 +392,6 @@ function SetupWave2DeadAnim()
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("I sense another wave of cannibals heading our way!"), SAY_SAY, 6500}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("I feel something...a place! They will arrive near the circles!"), SAY_SAY, 7500}})
       table.insert(wave2DeadAnim, {func = AnimCustomFunction, args = {natives[wiseNum], PutCircles, {}}})
-      table.insert(wave2DeadAnim, {func = AnimFollowGear, swh = false, args = {vCircs[1]}})
       table.insert(wave2DeadAnim, {func = AnimWait, args = {natives[wiseNum], 1500}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("We need to prevent their arrival!"), SAY_SAY, 4500}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("Go, quick!"), SAY_SAY, 2500}})
@@ -413,7 +412,6 @@ function SetupWave2DeadAnim()
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("I sense another wave of cannibals heading my way!"), SAY_THINK, 6500}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("I feel something...a place! They will arrive near the circles!"), SAY_SAY, 7500}})
       table.insert(wave2DeadAnim, {func = AnimCustomFunction, args = {natives[wiseNum], PutCircles, {}}})
-      table.insert(wave2DeadAnim, {func = AnimFollowGear, swh = false, args = {vCircs[1]}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("I need to prevent their arrival!"), SAY_THINK, 4500}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("If only I had a way..."), SAY_THINK, 3000}})
       table.insert(wave2DeadAnim, {func = AnimSay, args = {natives[wiseNum], loc("Oh, silly me! I forgot that I'm the shaman."), SAY_THINK, 6000}})
@@ -430,7 +428,6 @@ function SetupWave2DeadAnim()
     table.insert(wave2DeadAnim, {func = AnimSay, args = {cyborg, loc("I believe there's more of them."), SAY_SAY, 4000}})
     table.insert(wave2DeadAnim, {func = AnimSay, args = {cyborg, loc("I marked the place of their arrival. You're welcome!"), SAY_SAY, 6000}})
     table.insert(wave2DeadAnim, {func = AnimCustomFunction, args = {natives[wiseNum], PutCircles, {}}})
-    table.insert(wave2DeadAnim, {func = AnimFollowGear, swh = false, args = {vCircs[1]}})
     table.insert(wave2DeadAnim, {func = AnimCustomFunction, args = {deployedHog, DeployHog, {}}})
     if nativesNum > 1 then
 --      table.insert(wave2DeadAnim, {func = AnimCustomFunction, args = {natives[wiseNum], RestoreCyborg, {}}})
@@ -476,26 +473,26 @@ function IsolateNatives()
 end
 
 function PutCGI()
-  AddVisualGear(710, 299, vgtExplosion, 0, true)
-  AddVisualGear(690, 299, vgtExplosion, 0, true)
-  AddVisualGear(761, 209, vgtExplosion, 0, true)
-  AddVisualGear(921, 209, vgtExplosion, 0, true)
-  AddVisualGear(1081, 209, vgtExplosion, 0, true)
-  AddVisualGear(761, 189, vgtExplosion, 0, true)
-  AddVisualGear(921, 189, vgtExplosion, 0, true)
-  AddVisualGear(1081, 189, vgtExplosion, 0, true)
-  AddVisualGear(761, 169, vgtExplosion, 0, true)
-  AddVisualGear(921, 169, vgtExplosion, 0, true)
-  AddVisualGear(1081, 169, vgtExplosion, 0, true)
-  AddVisualGear(761, 149, vgtExplosion, 0, true)
-  AddVisualGear(921, 149, vgtExplosion, 0, true)
-  AddVisualGear(1081, 149, vgtExplosion, 0, true)
-  AddVisualGear(761, 129, vgtExplosion, 0, true)
-  AddVisualGear(921, 129, vgtExplosion, 0, true)
-  AddVisualGear(1081, 129, vgtExplosion, 0, true)
-  AddVisualGear(1120, 261, vgtExplosion, 0, true)
-  AddVisualGear(1140, 261, vgtExplosion, 0, true)
-  AddVisualGear(1160, 261, vgtExplosion, 0, true)
+  AddVisualGear(710, 299, vgtExplosion, 0, false)
+  AddVisualGear(690, 299, vgtExplosion, 0, false)
+  AddVisualGear(761, 209, vgtExplosion, 0, false)
+  AddVisualGear(921, 209, vgtExplosion, 0, false)
+  AddVisualGear(1081, 209, vgtExplosion, 0, false)
+  AddVisualGear(761, 189, vgtExplosion, 0, false)
+  AddVisualGear(921, 189, vgtExplosion, 0, false)
+  AddVisualGear(1081, 189, vgtExplosion, 0, false)
+  AddVisualGear(761, 169, vgtExplosion, 0, false)
+  AddVisualGear(921, 169, vgtExplosion, 0, false)
+  AddVisualGear(1081, 169, vgtExplosion, 0, false)
+  AddVisualGear(761, 149, vgtExplosion, 0, false)
+  AddVisualGear(921, 149, vgtExplosion, 0, false)
+  AddVisualGear(1081, 149, vgtExplosion, 0, false)
+  AddVisualGear(761, 129, vgtExplosion, 0, false)
+  AddVisualGear(921, 129, vgtExplosion, 0, false)
+  AddVisualGear(1081, 129, vgtExplosion, 0, false)
+  AddVisualGear(1120, 261, vgtExplosion, 0, false)
+  AddVisualGear(1140, 261, vgtExplosion, 0, false)
+  AddVisualGear(1160, 261, vgtExplosion, 0, false)
 end
 
 function TeleportNatives()
@@ -579,7 +576,7 @@ end
 
 function AfterHogDeadAnim()
   freshDead = nil
-  TurnTimeLeft = TurnTime
+  SetTurnTimeLeft(TurnTime)
 end
 
 --------------------------Anim skip functions--------------------------
@@ -590,7 +587,7 @@ function AfterAfterChoiceAnim()
   AddAmmo(speakerHog, amSwitch, 100)
   SetGearMessage(speakerHog, 0)
   SetState(speakerHog, 0)
-  TurnTimeLeft = -1
+  SetTurnTimeLeft(MAX_TURN_TIME)
   ShowMission(loc("Backstab"), loc("The food bites back"), loc("Defeat the cannibals"), 1, 4000)
   SpawnCrates()
 end
@@ -605,7 +602,7 @@ function AfterWave2Anim()
   SetGearMessage(CurrentHedgehog, 0)
   SetState(CurrentHedgehog, 0)
   SpawnCrates()
-  TurnTimeLeft = TurnTime
+  SetTurnTimeLeft(TurnTime)
 end
 
 function SkipWave2DeadAnim()
@@ -960,29 +957,28 @@ function SetupAmmo()
 end
 
 function AddHogs()
-	AddTeam(loc("Natives"), 29439, "Bone", "Island", "HillBilly", "cm_birdy")
+  AddTeam(loc("Tribe"), -2, "Bone", "Island", "HillBilly", "cm_birdy")
+  for i = 8, 9 do
+    natives[i] = AddHog(nativeNames[i], 0, 100, nativeHats[i])
+  end
+
+  AddTeam(loc("Natives"), -2, "Bone", "Island", "HillBilly", "cm_birdy")
   for i = 1, 7 do
     natives[i] = AddHog(nativeNames[i], 0, 100, nativeHats[i])
   end
   nativesNum = 7
 
-  AddTeam(loc("Tribe"), 29438, "Bone", "Island", "HillBilly", "cm_birdy")
-  for i = 8, 9 do
-    natives[i] = AddHog(nativeNames[i], 0, 100, nativeHats[i])
-  end
-
-
-  AddTeam(loc("Assault Team"), 14483456, "skull", "Island", "Pirate", "cm_vampire")
+  AddTeam(loc("Assault Team"), -1, "skull", "Island", "Pirate", "cm_vampire")
   for i = 1, 6 do
     cannibals[i] = AddHog(cannibalNames[i], 3, 50, "vampirichog")
   end
 
-  AddTeam(loc("Reinforcements"), 14483456, "skull", "Island", "Pirate", "cm_vampire")
+  AddTeam(loc("Reinforcements"), -1, "skull", "Island", "Pirate", "cm_vampire")
   for i = 7, 9 do
     cannibals[i] = AddHog(cannibalNames[i], 2, 50, "vampirichog")
   end
 
-  AddTeam(loc("011101001"), 14483456, "ring", "UFO", "Robot", "cm_binary")
+  AddTeam(loc("011101001"), -1, "ring", "UFO", "Robot", "cm_binary")
   cyborg = AddHog(loc("Unit 334a$7%;.*"), 0, 200, "cyborg1")
 
   for i = 1, 9 do
@@ -1013,7 +1009,8 @@ end
 
 function onGameInit()
 	Seed = 2
-	GameFlags = gfSolidLand
+	-- gfTagTeam makes it easier to skip the Tribe team
+	GameFlags = gfSolidLand + gfTagTeam
 	TurnTime = 60000 
 	CaseFreq = 0
 	MinesNum = 0
@@ -1109,7 +1106,7 @@ j = 0
 function onNewTurn()
   tmpVar = 0
   if AnimInProgress() then
-    TurnTimeLeft = -1
+    SetTurnTimeLeft(MAX_TURN_TIME)
     return
   end
 
@@ -1134,7 +1131,7 @@ function onNewTurn()
     else
       SetGearMessage(CurrentHedgehog, 0)
       --AnimSwitchHog(natives[leaksNum])
-      TurnTimeLeft = -1
+      SetTurnTimeLeft(MAX_TURN_TIME)
     end
   else
     if freshDead ~= nil and GetHogTeamName(CurrentHedgehog) == loc("Natives") then
