@@ -152,7 +152,7 @@ elderFace = "Left"
 
 goals = {
   [startDialogue] = {loc("First Blood"), loc("First Steps"), loc("Press [Left] or [Right] to move around, [Enter] to jump"), 1, 4000},
-  [onShroomAnim] = {loc("First Blood"), loc("A leap in a leap"), loc("Go on top of the flower") .. "|" .. loc("Hint: Press [Esc] to review the mission texts."), 1, 7000},
+  [onShroomAnim] = {loc("First Blood"), loc("A leap in a leap"), loc("Go on top of the flower") .. "|" .. loc("Hint: Hold down [M] to review the mission texts."), 1, 7000},
   [onFlowerAnim] = {loc("First Blood"), loc("Hightime"), loc("Collect the crate on the right.|Hint: Select the rope, [Up] or [Down] to aim, [Space] to fire, directional keys to move.|Ropes can be fired again in the air!"), 1, 7000},
   [tookParaAnim] = {loc("First Blood"), loc("Omnivore"), loc("Get on the head of the mole"), 1, 4000},
   [onMoleHeadAnim] = {loc("First Blood"), loc("The Leap of Faith"), loc("Use the parachute ([Space] while in air) to get the next crate"), 1, 4000},
@@ -171,6 +171,7 @@ function Skipanim(anim)
     ShowMission(unpack(goals[anim]))
   end
   if anim == startDialogue then
+    AnimSetGearPosition(youngh, 1952, 1365)
     HogTurnLeft(princess, false)
   end
 end
@@ -279,7 +280,7 @@ function AnimationSetup()
   table.insert(challengeFailedAnim, {func = AnimSwitchHog, args = {youngh}})
 
   AddSkipFunction(challengeCompletedAnim, Skipanim, {challengeCompletedAnim})
-  table.insert(challengeCompletedAnim, {func = AnimSay, args = {elderh, loc("The spirits of the ancerstors are surely pleased, Leaks A Lot."), SAY_SAY, 4000}, skipFunc = Skipanim, skipArgs = challengeCompletedAnim})
+  table.insert(challengeCompletedAnim, {func = AnimSay, args = {elderh, loc("The spirits of the ancestors are surely pleased, Leaks A Lot."), SAY_SAY, 4000}, skipFunc = Skipanim, skipArgs = challengeCompletedAnim})
   table.insert(challengeCompletedAnim, {func = AnimSay, args = {elderh, loc("You have proven yourself worthy to see our most ancient secret!"), SAY_SAY, 4000}})
   table.insert(challengeCompletedAnim, {func = AnimSay, args = {elderh, loc("The weapon in that last crate was bestowed upon us by the ancients!"), SAY_SAY, 4000}})
   table.insert(challengeCompletedAnim, {func = AnimSay, args = {elderh, loc("Use it with precaution!"), SAY_SAY, 4000}})
@@ -546,7 +547,7 @@ end
 
 function DoCratesColled()
   RemoveEventFunc(CheckTimesUp)
-  TurnTimeLeft = -1
+  SetTurnTimeLeft(MAX_TURN_TIME)
   AddCaption(loc("As the challenge was completed, Leaks A Lot set foot on the ground..."))
 end
 
@@ -573,7 +574,7 @@ function DoTimesUp()
   challengeFailed = true
   deleteCrate = true
   DeleteGear(crates[1])
-  TurnTimeLeft = -1
+  SetTurnTimeLeft(MAX_TURN_TIME)
   AddCaption(loc("And so happened that Leaks A Lot failed to complete the challenge! He landed, pressured by shame ..."))
   AddEvent(CheckChallengeFailed, {}, DoChallengeFailed, {}, 0)
 end
@@ -658,7 +659,7 @@ end
 function StartChallenge(time)
   cratesCollected = 0
   PutCrate(1)
-  TurnTimeLeft = time
+  SetTurnTimeLeft(time)
   ShowMission(loc("First Blood"), loc("The Crate Frenzy"), loc("Collect the crates within the time limit!|If you fail, you'll have to try again."), 1, 5000)
 end
 
@@ -674,7 +675,7 @@ function ChoiceDialog()
     loc("Press [Left] and [Right] to change the difficulty.") .. "| |" ..
     dstr .. "| |" ..
     loc("Press [Attack] to begin."),
-    0, 9999000)
+    0, 9999000, true)
 end
 
 function SetChoice()
@@ -684,11 +685,11 @@ function SetChoice()
 end
 
 function SetTime(time)
-  TurnTimeLeft = time
+  SetTurnTimeLeft(time)
 end
 
 function ResetTurnTime()
-  TurnTimeLeft = tTime
+  SetTurnTimeLeft(tTime)
   tTime = -1
 end
 
@@ -729,7 +730,7 @@ function onGameInit()
 	Theme = "Nature"
 
 
-	AddTeam(loc("Natives"), 29439, "Bone", "Island", "HillBilly", "cm_birdy")
+	AddTeam(loc("Natives"), -2, "Bone", "Island", "HillBilly", "cm_birdy")
 	youngh = AddHog(loc("Leaks A Lot"), 0, 100, "Rambo")
   elderh = AddHog(loc("Righteous Beard"), 0, 99, "IndianChief")
   princess = AddHog(loc("Fell From Heaven"), 0, 300, "tiara")
@@ -740,7 +741,7 @@ function onGameInit()
   AnimSetGearPosition(youngh, 1862, 1362)
   HogTurnLeft(youngh, false)
 
-  AddTeam(loc("Cannibals"), 14483456, "skull", "Island", "Pirate","cm_vampire")
+  AddTeam(loc("Cannibals"), -1, "skull", "Island", "Pirate","cm_vampire")
   cannibal = AddHog(loc("Brainiac"), 0, 5, "Zombi")
   AnimSetGearPosition(cannibal, 525, 1256)
   HogTurnLeft(cannibal, false)
@@ -751,7 +752,7 @@ end
 
 function onGameStart()
   progress = tonumber(GetCampaignVar("Progress"))
-  TurnTimeLeft = -1
+  SetTurnTimeLeft(MAX_TURN_TIME)
   FollowGear(youngh)
 	ShowMission(loc("A Classic Fairytale"), loc("First Blood"), loc("Finish your training|Hint: Animations can be skipped with the [Precise] key."), -amSkip, 0)
   HideHog(cannibal)
@@ -846,7 +847,7 @@ function onNewTurn()
   end
   SwitchHog(youngh)
   FollowGear(youngh)
-  TurnTimeLeft = -1
+  SetTurnTimeLeft(MAX_TURN_TIME)
 end
 
 function onGearDamage(gear, damage)
