@@ -83,11 +83,11 @@ guard2.x = 3400
 guard2.y = 1800
 -- Planetary Association of the Hedgehogs
 teamA.name = loc("PAotH")
-teamA.color = 0x38D61C -- green
+teamA.color = -6
 teamB.name = loc("Guards")
-teamB.color = 0x0072FF -- blue
+teamB.color = -2
 teamC.name = loc("Hog Solo")
-teamC.color = 0x38D61C -- green
+teamC.color = -6
 
 -------------- LuaAPI EVENT HANDLERS ------------------
 function onGameInit()
@@ -306,7 +306,7 @@ function onNewTurn()
 			getReadyForRumble = false
 		else
 			if guard1.keepTurning then
-				TurnTimeLeft = -1
+				SetTurnTimeLeft(MAX_TURN_TIME)
 			end
 		end
 	elseif not onHeroDeath() and CurrentHedgehog == director.gear or CurrentHedgehog == doctor.gear then
@@ -468,7 +468,7 @@ function moonLanding(gear)
 			SaveCampaignVar("HeroHealth",GetHealth(hero.gear))
 		end
 		AnimCaption(hero.gear,loc("Welcome to the moon!"))
-		TurnTimeLeft = -1
+		SetTurnTimeLeft(MAX_TURN_TIME)
 		SaveCampaignVar("HeroHealth", GetHealth(hero.gear))
 		SaveCampaignVar("Planet", "moon")
 		SaveCampaignVar("UnlockedMissions", "3")
