@@ -44,11 +44,11 @@ local enemies = {
 -- teams
 local teamA = {
 	name = loc("Hog Solo"),
-	color = tonumber("38D61C",16) -- green
+	color = -6
 }
 local teamB = {
 	name = loc("5 Deadly Hogs"),
-	color = tonumber("FF0000",16) -- red
+	color = -1
 }
 -- After hero killed an enemy, his weapons will be reset in the next round
 local heroWeaponResetPending = false
@@ -108,7 +108,7 @@ function onNewTurn()
 	battleStarted = true
 	if firstTurn then
 		-- Generous ready time in first turn to more time to read the mission panel
-		ReadyTimeLeft = 35000
+		SetReadyTimeLeft(35000)
 		firstTurn = false
 	end
 	if CurrentHedgehog ~= hero.gear then
