@@ -29,7 +29,7 @@ local hero = {
 -- teams
 local teamA = {
 	name = loc("Hog Solo"),
-	color = tonumber("38D61C",16) -- green
+	color = -6
 }
 -- creates & targets
 local rcCrates = {
@@ -61,7 +61,7 @@ local flameCounter = 0
 function onGameInit()
 	GameFlags = gfOneClanMode
 	Seed = 1
-	TurnTime = -1
+	TurnTime = MAX_TURN_TIME
 	Ready = 30000
 	CaseFreq = 0
 	MinesNum = 0
@@ -169,7 +169,7 @@ function heroDeath(gear)
 end
 
 function lose(gear)
-	AddCaption(loc("Out of ammo!"), 0xFFFFFFFF, capgrpMessage2)
+	AddCaption(loc("Out of ammo!"), capcolDefault, capgrpMessage2)
 	PlaySound(sndStupid, hero.gear)
 	gameOver()
 end
