@@ -73,11 +73,11 @@ bandit5.y = 600
 bandit5.frozen = false
 bandit5.roundsToUnfreeze = 0
 teamA.name = loc("Allies")
-teamA.color = 0x38D61C -- green
+teamA.color = -6
 teamB.name = loc("Frozen Bandits")
-teamB.color = 0x0072FF -- blue
+teamB.color = -2
 teamC.name = loc("Hog Solo")
-teamC.color = 0x38D61C -- green
+teamC.color = -6
 
 -------------- LuaAPI EVENT HANDLERS ------------------
 
@@ -240,7 +240,7 @@ function onNewTurn()
 	if not heroVisitedAntiFlyArea and CurrentHedgehog ~= hero.gear then
 		EndTurn(true)
 	elseif not heroVisitedAntiFlyArea and CurrentHedgehog == hero.gear then
-		TurnTimeLeft = -1
+		SetTurnTimeLeft(MAX_TURN_TIME)
 	elseif not heroAtFinalStep and (CurrentHedgehog == bandit1.gear or CurrentHedgehog == bandit4.gear or CurrentHedgehog == bandit5.gear) then
 		AnimSwitchHog(hero.gear)
 		EndTurn(true)
@@ -454,13 +454,13 @@ function heroFinalStep(gear)
 	SaveCampaignVar("HeroHealth", GetHealth(hero.gear))
 	SaveCampaignVar("HeroAmmoIce01IceGun", GetAmmoCount(hero.gear, amIceGun))
 	SaveCampaignVar("HeroAmmoIce01Bazooka", GetAmmoCount(hero.gear, amBazooka))
-	AddCaption(loc("Checkpoint reached!"), 0xFFFFFFFF, capgrpMessage2)
+	AddCaption(loc("Checkpoint reached!"), capcolDefault, capgrpMessage2)
 end
 
 function columnCheckPoint(gear)
 	saveCheckpoint("2")
 	SaveCampaignVar("HeroHealth", GetHealth(hero.gear))
-	AddCaption(loc("Checkpoint reached!"), 0xFFFFFFFF, capgrpMessage2)
+	AddCaption(loc("Checkpoint reached!"), capcolDefault, capgrpMessage2)
 	SaveCampaignVar("HeroAmmoIce01IceGun", GetAmmoCount(hero.gear, amIceGun))
 	SaveCampaignVar("HeroAmmoIce01Bazooka", GetAmmoCount(hero.gear, amBazooka))
 end
