@@ -12,6 +12,7 @@
 ]]
 
 HedgewarsScriptLoad("/Scripts/Locale.lua")
+HedgewarsScriptLoad("/Scripts/Achievements.lua")
 
 local hog			-- Hog gear
 local weaponSelected = false	-- Player has selected the weapon
@@ -37,7 +38,7 @@ function onGameInit()
 	Seed = 0
 	Theme = "Nature"
 	MapGen = mgDrawn
-	TurnTime = 9999000
+	TurnTime = MAX_TURN_TIME
 	Explosives = 0
 	MinesNum = 0
 	CaseFreq = 0
@@ -46,7 +47,7 @@ function onGameInit()
 
 	------ TEAM LIST ------
 
-	AddTeam(loc("Bazooka Team"), 0xFF0204, "Flower", "Earth", "Default", "hedgewars")
+	AddTeam(loc("Bazooka Team"), -1, "Flower", "Earth", "Default", "hedgewars")
 	hog = AddHog(loc("Greenhorn"), 0, 100, "NoHat")
 	SetGearPosition(hog, 1485, 2001)
 	SetEffect(hog, heResurrectable, 1)
@@ -54,10 +55,13 @@ function onGameInit()
 	SendHealthStatsOff()
 end
 
-function onGearResurrect(gear)
+function onGearResurrect(gear, vGear)
 	if gear == hog then
 		flawless = false
 		SetGearPosition(hog, 1485, 2001)
+		if vGear then
+			SetVisualGearValues(vGear, GetX(hog), GetY(hog))
+		end
 		AddCaption(loc("Your hedgehog has been revived!"))
 	end
 end
@@ -171,7 +175,7 @@ function newGamePhase()
 		end
 	elseif gamePhase == 5 then
 		ShowMission(loc("Basic Bazooka Training"), loc("High Target"),
-		loc("By the way, not only bazookas will bounce on water, but also greandes and many other things.").."|"..
+		loc("By the way, not only bazookas will bounce on water, but also grenades and many other things.").."|"..
 		loc("The next target is high in the sky."),
 		2, 8000)
 		SetWind(-33)
@@ -190,6 +194,9 @@ function newGamePhase()
 		AddAmmo(CurrentHedgehog, amBazooka, 0)
 		if shotsFired > maxTargets then
 			flawless = false
+		else
+			-- For 100% accuracy
+			awardAchievement(loc("Bazooka Master"))
 		end
 		if flawless then
 			PlaySound(sndFlawless, hog)
@@ -217,6 +224,12 @@ function onHogAttack(ammoType)
 	end
 end
 
+function onAttack()
+	if GetCurAmmoType() == amBazooka then
+		HideMission()
+	end
+end
+
 function onGearAdd(gear)
 	if GetGearType(gear) == gtTarget then
 		targetsLeft = targetsLeft + 1
