@@ -62,7 +62,7 @@ TargetPos[2] = {
 	InfFuel = true,
 	MessageTime = 10000,
 	Message = loc("Get to the crate using your flying saucer!") .. "|" ..
-	loc("Press [Attack] (space bar by default) to start,|repeadedly tap the up, left and right movement keys to accelerate.") .. "|" ..
+	loc("Press [Attack] (space bar by default) to start,|repeatedly tap the up, left and right movement keys to accelerate.") .. "|" ..
 	loc("Try to land softly, as you can still take fall damage!"), }
 TargetPos[3] = {
 	Targets = {{ X = 689, Y = 58 }},
@@ -140,7 +140,7 @@ TargetPos[9] = {
 		loc("You have to destroy two targets, but the previous technique would be very difficult or dangerous to use.") .. "|" ..
 		loc("So you are able to launch projectiles into your aiming direction, always at full power.") .."|"..
 		loc("To launch a projectile in mid-flight, hold [Precise] and press [Long jump].") .. "|" ..
-		loc("You can even change your aiming direction in mid-flight if you first hold [Precice] and then press [Up] or [Down].") .. "|" ..
+		loc("You can even change your aiming direction in mid-flight if you first hold [Precise] and then press [Up] or [Down].") .. "|" ..
 		loc("Tip: Changing your aim while flying is very difficult, so adjust it before you take off."),
 	Ammo = { [amJetpack] = 1, },
 	Respawn = { X = 1764, Y = 916 },
@@ -184,7 +184,7 @@ TargetPos[11] = {
 	InfFuel = true, }
 TargetPos[12] = { Modifier = true, Func = function()
 	Objective = true
-	AddCaption(loc("Training complete!"), 0xFFFFFFFF, capgrpGameState)
+	AddCaption(loc("Training complete!"), capcolDefault, capgrpGameState)
 	Info(loc("Training complete!"), loc("Good bye!"), 4, 5000)
 
 	if SaucerGear ~= nil then
@@ -198,7 +198,7 @@ TargetPos[12] = { Modifier = true, Func = function()
 	SendStat(siCustomAchievement, loc("Good job!"))
 	SendStat(siPlayerKills, "0", loc("Hogonauts"))
 
-	TurnTimeLeft = 0
+	EndTurn(true)
 	EndGame()
 end,
 }
@@ -267,6 +267,7 @@ function AutoSpawn() -- Auto-spawn the next target after you've obtained the cur
 	else
 		InfFuel = false
 	end
+	UpdateInfFuel()
 
 	-- Func (if present) will be run instead of the ordinary spawning handling
 	if TargetPos[TargetNumber].Modifier then -- If there is a modifier, run the function
@@ -291,7 +292,7 @@ function AutoSpawn() -- Auto-spawn the next target after you've obtained the cur
 	SpawnTargets()
 
 	if TargetNumber > 1 then
-		AddCaption(loc("Next target is ready!"), 0xFFFFFFFF, capgrpMessage2)
+		AddCaption(loc("Next target is ready!"), capcolDefault, capgrpMessage2)
 	end
 end
 
@@ -356,6 +357,7 @@ function ResetCurrentTarget()
 	else
 		InfFuel = false
 	end
+	UpdateInfFuel()
 
 	SetGearPosition(Player, X, Y)
 end
@@ -363,8 +365,8 @@ end
 function onGameInit()
 	Seed = 1
 	GameFlags = gfInfAttack + gfOneClanMode + gfSolidLand + gfDisableWind
-	TurnTime = 2000000 --[[ This rffectively hides the turn time; a turn time above 1000s is not displayed.
-				We will also ensure this timer always stays above 999s later ]]
+	TurnTime = MAX_TURN_TIME --[[ This effectively hides the turn time; a turn time above 1000s is not displayed.
+			   	     We will also ensure this timer always stays above 999s later ]]
 	CaseFreq = 0
 	MinesNum = 0
 	Explosives = 0
@@ -375,7 +377,7 @@ function onGameInit()
 	HealthDecrease = 0
 
 	-- Team name is a pun on “hedgehog” and “astronauts”
-	AddTeam( loc( "Hogonauts" ), 0xDDDD00, "earth", "Earth", "Default", "cm_galaxy" )
+	AddTeam( loc( "Hogonauts" ), -9, "earth", "Earth", "Default", "cm_galaxy" )
 
 	-- Hedgehog name is a pun on “Neil Armstrong”
 	Player = AddHog( loc( "Neil Hogstrong" ), 0, 1, "NoHat" )
@@ -430,6 +432,7 @@ function onGearAdd(Gear)
 		if (TargetNumber == LaunchTarget or TargetNumber == UnderwaterAttackTarget) and BazookasLeft > 0 then
 			AddAmmo(Player, amBazooka, BazookasLeft)
 		end
+		UpdateInfFuel()
 		-- If player starts using saucer, the player probably finished reading and the mission panel
 		-- would just get in the way. So we hide it!
 		HideMission()
@@ -457,7 +460,7 @@ function onGearDelete(Gear)
 		if TargetsRemaining <= 0 then
 			if TargetNumber == BoomTarget or not HasHedgehogLandedYet() then
 				if SaucerGear then
-					AddCaption(loc("Objective completed! Now land safely."), 0xFFFFFFFF, capgrpMessage2)
+					AddCaption(loc("Objective completed! Now land safely."), capcolDefault, capgrpMessage2)
 				end
 				Check = true
 				CheckTimer = 500
@@ -487,7 +490,7 @@ function onGearDelete(Gear)
 	end
 	if Gear == Barrels[2] then
 		Barrels[2] = nil
-		AddCaption(loc("Kaboom!"), 0xFFFFFFFF, capgrpMessage)
+		AddCaption(loc("Kaboom!"), capcolDefault, capgrpMessage)
 	end
 end
 
@@ -501,7 +504,7 @@ end
 
 function onGameTick20()
 	if (TurnTimeLeft < 1500000 and not Objective) then
-		TurnTimeLeft = TurnTime
+		SetTurnTimeLeft(TurnTime)
 	end
 	if Check then
 		CheckTimer = CheckTimer - 20
@@ -513,7 +516,7 @@ function onGameTick20()
 			end
 		end
 	end
-	if GrenadeExploded and TargetNumber == BoomTarget then
+	if GrenadeExploded and TargetNumber == BoomTarget and GetHealth(Player) then
 		GrenadeTimer = GrenadeTimer + 20
 		if GrenadeTimer > 1500 then
 			GrenadeTimer = 0
@@ -521,25 +524,23 @@ function onGameTick20()
 			GrenadeExploded = false
 			if SaucerGear and TargetNumber == BoomTarget and TargetsRemaining > 0 then
 				PlaySound(sndShotgunReload)
-				AddCaption(loc("+1 Grenade"), 0xDDDD00FF, capgrpAmmoinfo)
+				AddCaption(loc("+1 Grenade"), GetClanColor(GetHogClan(Player)), capgrpAmmoinfo)
 				AddAmmo(Player, amGrenade, 1)
 			end
 		end
 	end
-	ResetFuel()
 end
 
--- Used to ensure infinite fuel
-function ResetFuel()
-	if SaucerGear and InfFuel then
-		SetHealth(SaucerGear, 2000)
+function UpdateInfFuel()
+	if SaucerGear then
+		if InfFuel then
+			SetHealth(SaucerGear, JETPACK_FUEL_INFINITE)
+		elseif GetHealth(SaucerGear == JETPACK_FUEL_INFINITE) then
+			SetHealth(SaucerGear, 2000)
+		end
 	end
 end
 
-onUp = ResetFuel
-onLeft = ResetFuel
-onRight = ResetFuel
-
 function onGearDamage(Gear)
 	if Gear == Player then
 		CleanUpGears()
@@ -548,14 +549,17 @@ function onGearDamage(Gear)
 	end
 end
 
-function onGearResurrect(Gear)
+function onGearResurrect(Gear, VGear)
 	if Gear == Player then
-		AddCaption(loc("Oh no! You have died. Try again!"), 0xFFFFFFFF, capgrpMessage2)
+		AddCaption(loc("Oh no! You have died. Try again!"), capcolDefault, capgrpMessage2)
 		ResetCurrentTarget()
+		if VGear then
+			SetVisualGearValues(VGear, GetX(Gear), GetY(Gear))
+		end
 	end
 end
 
 function onSkipTurn()
-	AddCaption(loc("Try again!"), 0xFFFFFFFF, capgrpMessage2)
+	AddCaption(loc("Try again!"), capcolDefault, capgrpMessage2)
 	ResetCurrentTarget()
 end
