@@ -6,7 +6,7 @@
 -- by mikade
 
 -- feel free to add map specific walls to LoadConfig, or post additional
--- wall suggestions on our forum at: http://www.hedgewars.org/forum
+-- wall suggestions on our forum at: https://www.hedgewars.org/forum
 
 ----------------
 --0.1
@@ -705,7 +705,9 @@ function DrawBlip(gear)
 		baseColor = GetClanColor(GetHogClan(CurrentHedgehog))
 		alpha = rAlpha
 	end
-	SetVisualGearValues(getGearValue(gear,"CIRC"), getGearValue(gear,"RX"), getGearValue(gear,"RY"), 100, 255, 1, 10, 0, radius, 3, baseColor-alpha)
+	if getGearValue(gear,"CIRC") ~= nil then
+		SetVisualGearValues(getGearValue(gear,"CIRC"), getGearValue(gear,"RX"), getGearValue(gear,"RY"), 100, 255, 1, 10, 0, radius, 3, baseColor-alpha)
+	end
 end
 
 function TrackRadarBlip(gear)
@@ -874,7 +876,7 @@ end
 function onGearWaterSkip(gear)
 	if gear == CurrentHedgehog then
 		hasSurfed = true
-		AddCaption(loc("Surfer!"), 0xFFFFFFFF, capgrpMessage2)
+		AddCaption(loc("Surfer!"), capcolDefault, capgrpMessage2)
 	end
 end
 
@@ -882,7 +884,7 @@ end
 function WallHit(id, zXMin,zYMin, zWidth, zHeight)
 
 	if wTouched[id] == false then
-		tempE = AddVisualGear(GetX(CurrentHedgehog), GetY(CurrentHedgehog), vgtBigExplosion, 0, false)
+		AddVisualGear(GetX(CurrentHedgehog), GetY(CurrentHedgehog), vgtBigExplosion, 0, false)
 		PlaySound(sndExplosion)
 		wallsLeft = wallsLeft - 1
 
@@ -890,7 +892,7 @@ function WallHit(id, zXMin,zYMin, zWidth, zHeight)
 			AddCaption(loc("All walls touched!"))
 			allWallsHit = true
 			if (requireSurfer == true) and (hasSurfed == false) then
-				AddCaption(loc("Go surf!"), 0xFFFFFFFF, capgrpMessage2)
+				AddCaption(loc("Go surf!"), capcolDefault, capgrpMessage2)
 			end
 		else
 			AddCaption(string.format(loc("Walls left: %d"), wallsLeft))
@@ -900,7 +902,7 @@ function WallHit(id, zXMin,zYMin, zWidth, zHeight)
 
 	wTouched[id] = true
 	if #wTouched > 0 then
-		tempE = AddVisualGear(GetX(CurrentHedgehog), GetY(CurrentHedgehog), vgtSmoke, 0, false)
+		AddVisualGear(GetX(CurrentHedgehog), GetY(CurrentHedgehog), vgtSmoke, 0, false)
 	end
 
 end
@@ -925,10 +927,7 @@ function BorderSpark(zXMin,zYMin, zWidth, zHeight, bCol)
 		local eY = zYMin + GetRandom(zHeight+10)
 
 		local tempE = AddVisualGear(eX, eY, vgtDust, 0, false)
-		if tempE ~= 0 then
-			local g1, g2, g3, g4, g5, g6, g7, g8, g9, g10 = GetVisualGearValues(tempE)
-			SetVisualGearValues(tempE, eX, eY, g3, g4, g5, g6, g7, 1, g9, bCol )
-		end
+		SetVisualGearValues(tempE, eX, eY, nil, nil, nil, nil, nil, 1, nil, bCol )
 	end
 
 end
@@ -963,7 +962,7 @@ function onLJump()
 		SetInputMask(0xFFFFFFFF)
 		AddCaption(loc("Configuration accepted."), msgColorTech, capgrpMessage)
 		if GetGameFlag(gfPlaceHog) then
-			TurnTimeLeft = PlacementTime
+			SetTurnTimeLeft(PlacementTime)
 			AddAmmo(CurrentHedgehog, amTeleport, 100)
 			SetWeapon(amTeleport)
 			AddCaption(
@@ -973,8 +972,8 @@ function onLJump()
 			)
 			roundN = 2
 		else
-			TurnTimeLeft = TurnTime
-			AddCaption(string.format(loc("Let's go, %s!"), GetHogTeamName(CurrentHedgehog)), 0xFFFFFFFF, capgrpMessage2)
+			SetTurnTimeLeft(TurnTime)
+			AddCaption(string.format(loc("Let's go, %s!"), GetHogTeamName(CurrentHedgehog)), capcolDefault, capgrpMessage2)
 			roundN = 100
 			wallsLeft = #wTouched
 			allowCrate = true
@@ -1281,7 +1280,7 @@ function onNewTurn()
 		if roundN < 2 then
 			SetWeapon(amSkip)
 			AddAmmo(CurrentHedgehog, amTeleport, 0)
-			TurnTimeLeft = -1
+			SetTurnTimeLeft(MAX_TURN_TIME)
 			SetInputMask(0)
 		end
 		if roundN == 2 then
@@ -1338,7 +1337,7 @@ function onNewTurn()
 	end
 
 	if roundN == 1 then
-		TurnTimeLeft = -1
+		SetTurnTimeLeft(MAX_TURN_TIME)
 		SetInputMask(0)
 		allowCrate = false
 		UpdateMenu()
@@ -1536,12 +1535,22 @@ end
 
 function HandleStartingStage()
 
-	temp = menu[menuIndex].line
-	menu[menuIndex].line = "--> " .. menu[menuIndex].line
+	local renderedLines = {}
+	for m = 1, #menu do
+		local marker
+		local line = menu[m].line
+		if m == menuIndex then
+			marker = "▶"
+		else
+			marker = "▷"
+			line = string.gsub(line, ":", "\\:")
+		end
+		table.insert(renderedLines, marker .. " " .. line)
+	end
 
 	missionComment = ""
-	for i = 1, #menu do
-		missionComment = missionComment .. menu[i].line
+	for l = 1, #renderedLines do
+		missionComment = missionComment .. renderedLines[l]
 	end
 
 	ShowMission	(
@@ -1550,11 +1559,9 @@ function HandleStartingStage()
 				preMenuCfg..
 				missionComment ..
 				postMenuCfg ..
-				"", 2, 9999000
+				"", 2, 9999000, true
 				)
 
-	menu[menuIndex].line = temp
-
 end
 
 function onGameTick()
@@ -1643,11 +1650,14 @@ function onGearAdd(gear)
 
 		trackGear(gear)
 
-		table.insert(rCirc, AddVisualGear(0,0,vgtCircle,0,true) )
-		setGearValue(gear,"CIRC",rCirc[#rCirc])
+		local vg = AddVisualGear(0, 0, vgtCircle, 0, true)
+		if vg then
+			table.insert(rCirc, vg)
+			setGearValue(gear,"CIRC",vg)
+			SetVisualGearValues(vg, 0, 0, 100, 255, 1, 10, 0, 40, 3, 0xff00ffff)
+		end
 		setGearValue(gear,"RX",0)
 		setGearValue(gear,"RY",0)
-		SetVisualGearValues(rCirc[#rCirc], 0, 0, 100, 255, 1, 10, 0, 40, 3, 0xff00ffff)
 
 		allowCrate = false
 		crateSpawned = true
@@ -1684,7 +1694,8 @@ function onGearDelete(gear)
 		crateGearsInGame = crateGearsInGame - 1
 
 		for i = 1, #rCirc do
-			if rCirc[i] == getGearValue(gear,"CIRC") then
+			local CIRC = getGearValue(gear,"CIRC")
+			if CIRC ~= nil and rCirc[i] == CIRC then
 				DeleteVisualGear(rCirc[i])
 				table.remove(rCirc, i)
 			end
